@@ -1,8 +1,8 @@
 from aiolimiter import AsyncLimiter
 
 from a_sync._typing import *
-from a_sync.modifiers.manager import ModifierManager, valid_modifiers
-from a_sync.semaphores import ThreadsafeSemaphore
+from a_sync import primitives
+from a_sync.modifiers.manager import valid_modifiers
 
 
 def get_modifiers_from(thing: Union[dict, type, object]) -> ModifierKwargs:
@@ -13,7 +13,7 @@ def get_modifiers_from(thing: Union[dict, type, object]) -> ModifierKwargs:
 
 def apply_class_defined_modifiers(attrs_from_metaclass: dict):
     if 'semaphore' in attrs_from_metaclass and isinstance(val := attrs_from_metaclass['semaphore'], int):
-        attrs_from_metaclass['semaphore'] = ThreadsafeSemaphore(val)
+        attrs_from_metaclass['semaphore'] = primitives.ThreadsafeSemaphore(val)
     if "runs_per_minute" in attrs_from_metaclass and isinstance(val := attrs_from_metaclass['runs_per_minute'], int):
         attrs_from_metaclass['runs_per_minute'] = AsyncLimiter(val)
         
\ No newline at end of file
